@@ -50,6 +50,8 @@ def exec_polqa_test():
         # samplerate = info[3]
         global_result.mosResult = copy.deepcopy(constMosResult)
         startvqt(os.path.abspath(srf), os.path.abspath(tsf), sr)
+        if '-0.0' == global_result.mosResult['mos']:
+            time.sleep(5)
         curruslt['result'] = global_result.mosResult
 
         socket = SocketClient(global_result.machost, global_result.PORT)
