@@ -448,4 +448,4 @@ class computeAudioQuality():
         -------
 
         """
-        return cal_clip_index(pcm2wav(self.refFile, sample_rate=self.samplerate))
\ No newline at end of file
+        return cal_clip_index(pcm2wav(self.testFile, sample_rate=self.samplerate))
\ No newline at end of file
