@@ -20,12 +20,10 @@ def resample(infile,target_amplerate,outfile=None):
     import platform
     #mydll = None
     cur_paltform = platform.platform().split('-')[0]
-    print(cur_paltform)
     if cur_paltform == 'Windows':
         mydll = ctypes.windll.LoadLibrary(sys.prefix + '/resampler.dll')
     if cur_paltform == 'macOS':
         mydll = CDLL(sys.prefix + '/resample.dylib')
-    print(mydll)
     if outfile is None:
         outfile = infile[:-4] +'_' +str(target_amplerate) + '.wav'
     infile_ref = c_char_p(bytes(infile.encode('utf-8')))
